summaryrefslogtreecommitdiff
path: root/Master/texmf-dist/tex/context/base/mkiv/node-fnt.lua
diff options
context:
space:
mode:
authorKarl Berry <karl@freefriends.org>2020-03-05 00:48:46 +0000
committerKarl Berry <karl@freefriends.org>2020-03-05 00:48:46 +0000
commitf210bce174e1f2f05305ab03e88e120a1cbfc4da (patch)
tree5c4e2ad096b5c745e859516ac3196fa0864292d5 /Master/texmf-dist/tex/context/base/mkiv/node-fnt.lua
parent35fd641a3546acc0c62e0aa7f134888e36da30d4 (diff)
context (from cont-tmf.zip of Feb 17 16:00, size 116339406)
git-svn-id: svn://tug.org/texlive/trunk@54086 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Master/texmf-dist/tex/context/base/mkiv/node-fnt.lua')
-rw-r--r--Master/texmf-dist/tex/context/base/mkiv/node-fnt.lua15
1 files changed, 8 insertions, 7 deletions
diff --git a/Master/texmf-dist/tex/context/base/mkiv/node-fnt.lua b/Master/texmf-dist/tex/context/base/mkiv/node-fnt.lua
index 01d7e42e5d6..1b245639b78 100644
--- a/Master/texmf-dist/tex/context/base/mkiv/node-fnt.lua
+++ b/Master/texmf-dist/tex/context/base/mkiv/node-fnt.lua
@@ -43,7 +43,6 @@ local handlers = nodes.handlers
local nuts = nodes.nuts
-local getattr = nuts.getattr
local getid = nuts.getid
local getsubtype = nuts.getsubtype
local getdisc = nuts.getdisc
@@ -51,7 +50,9 @@ local getnext = nuts.getnext
local getprev = nuts.getprev
local getboth = nuts.getboth
local getdata = nuts.getdata
+local getglyphdata = nuts.getglyphdata
----- getdisc = nuts.getdisc
+
local setchar = nuts.setchar
local setlink = nuts.setlink
local setnext = nuts.setnext
@@ -179,7 +180,7 @@ local function start_trace(head)
local char, id = isglyph(n)
if char then
local font = id
- local attr = getattr(n,0) or 0
+ local attr = getglyphdata(n) or 0
report_fonts("font %03i, dynamic %03i, glyph %C",font,attr,char)
elseif id == disc_code then
report_fonts("[disc] %s",nodes.listtoutf(n,true,false,n))
@@ -209,12 +210,12 @@ do
local usedfonts
local attrfonts
- local basefonts
+ local basefonts -- could be reused
local basefont
local prevfont
local prevattr
local variants
- local redundant
+ local redundant -- could be reused
local firstnone
local lastfont
local lastproc
@@ -316,8 +317,8 @@ do
-- metafun manual (with some 2500 single char lists) the difference is just noise.
for n, char, font in nextchar, head do
- -- local attr = (none and prevattr) or getattr(n,0) or 0 -- zero attribute is reserved for fonts in context
- local attr = getattr(n) or 0 -- zero attribute is reserved for fonts in context
+ -- local attr = (none and prevattr) or getglyphdata(n) or 0 -- zero attribute is reserved for fonts in context
+ local attr = getglyphdata(n) or 0 -- zero attribute is reserved for fonts in context
if font ~= prevfont or attr ~= prevattr then
prevfont = font
prevattr = attr
@@ -440,7 +441,7 @@ do
firstnone = nil
basefont = nil
for n, char, font in nextchar, r do
- local attr = getattr(n) or 0 -- zero attribute is reserved for fonts in context
+ local attr = getglyphdata(n) or 0 -- zero attribute is reserved for fonts in context
if font ~= prevfont or attr ~= prevattr then
prevfont = font
prevattr = attr